from .return_class import AbstractApiClass


class HostedDatabaseSnapshot(AbstractApiClass):
    """
        Hosted Database Snapshot

        Args:
            client (ApiClient): An authenticated API Client instance
            hostedDatabaseSnapshotId (id): The ID of the hosted database snapshot
            srcHostedDatabaseId (id): The ID of the source hosted database
            createdAt (str): The creation timestamp
            updatedAt (str): The last update timestamp
            lifecycle (str): The lifecycle of the hosted database snapshot
    """

    def __init__(self, client, hostedDatabaseSnapshotId=None, srcHostedDatabaseId=None, createdAt=None, updatedAt=None, lifecycle=None):
        super().__init__(client, hostedDatabaseSnapshotId)
        self.hosted_database_snapshot_id = hostedDatabaseSnapshotId
        self.src_hosted_database_id = srcHostedDatabaseId
        self.created_at = createdAt
        self.updated_at = updatedAt
        self.lifecycle = lifecycle
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'hosted_database_snapshot_id': repr(self.hosted_database_snapshot_id), f'src_hosted_database_id': repr(
            self.src_hosted_database_id), f'created_at': repr(self.created_at), f'updated_at': repr(self.updated_at), f'lifecycle': repr(self.lifecycle)}
        class_name = "HostedDatabaseSnapshot"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'hosted_database_snapshot_id': self.hosted_database_snapshot_id, 'src_hosted_database_id': self.src_hosted_database_id,
                'created_at': self.created_at, 'updated_at': self.updated_at, 'lifecycle': self.lifecycle}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .api_class import WorkflowGraphNode
from .return_class import AbstractApiClass


class WorkflowGraphNodeDetails(AbstractApiClass):
    """
        A workflow graph node in the workflow graph.

        Args:
            client (ApiClient): An authenticated API Client instance
            packageRequirements (list[str]): A list of package requirements that the node source code will need.
            connectors (dict): A dictionary of connectors that the node source code will need.
            workflowGraphNode (WorkflowGraphNode): The workflow graph node object.
    """

    def __init__(self, client, packageRequirements=None, connectors=None, workflowGraphNode={}):
        super().__init__(client, None)
        self.package_requirements = packageRequirements
        self.connectors = connectors
        self.workflow_graph_node = client._build_class(
            WorkflowGraphNode, workflowGraphNode)
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'package_requirements': repr(self.package_requirements), f'connectors': repr(
            self.connectors), f'workflow_graph_node': repr(self.workflow_graph_node)}
        class_name = "WorkflowGraphNodeDetails"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'package_requirements': self.package_requirements, 'connectors': self.connectors,
                'workflow_graph_node': self._get_attribute_as_dict(self.workflow_graph_node)}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class HostedApp(AbstractApiClass):
    """
        Hosted App

        Args:
            client (ApiClient): An authenticated API Client instance
            hostedAppId (id): The ID of the hosted app
            deploymentConversationId (id): The ID of the deployment conversation
            name (str): The name of the hosted app
            createdAt (str): The creation timestamp
    """

    def __init__(self, client, hostedAppId=None, deploymentConversationId=None, name=None, createdAt=None):
        super().__init__(client, hostedAppId)
        self.hosted_app_id = hostedAppId
        self.deployment_conversation_id = deploymentConversationId
        self.name = name
        self.created_at = createdAt
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'hosted_app_id': repr(self.hosted_app_id), f'deployment_conversation_id': repr(
            self.deployment_conversation_id), f'name': repr(self.name), f'created_at': repr(self.created_at)}
        class_name = "HostedApp"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'hosted_app_id': self.hosted_app_id, 'deployment_conversation_id':
                self.deployment_conversation_id, 'name': self.name, 'created_at': self.created_at}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .database_column_feature_mapping import DatabaseColumnFeatureMapping
from .return_class import AbstractApiClass


class InferredDatabaseColumnToFeatureMappings(AbstractApiClass):
    """
        Autocomplete mappings for database to connector columns

        Args:
            client (ApiClient): An authenticated API Client instance
            databaseColumnToFeatureMappings (DatabaseColumnFeatureMapping): Database columns feature mappings
    """

    def __init__(self, client, databaseColumnToFeatureMappings={}):
        super().__init__(client, None)
        self.database_column_to_feature_mappings = client._build_class(
            DatabaseColumnFeatureMapping, databaseColumnToFeatureMappings)
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'database_column_to_feature_mappings': repr(
            self.database_column_to_feature_mappings)}
        class_name = "InferredDatabaseColumnToFeatureMappings"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'database_column_to_feature_mappings': self._get_attribute_as_dict(
            self.database_column_to_feature_mappings)}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class DaemonTaskInstance(AbstractApiClass):
    """
        A daemon task instance representing a single run of a daemon task.

        Args:
            client (ApiClient): An authenticated API Client instance
            daemonTaskVersion (str): The unique identifier for this task instance.
            daemonTaskId (str): The id of the parent daemon task.
            deploymentConversationId (str): The deployment conversation id for this instance.
            lifecycle (str): The lifecycle status (PENDING, EXECUTING, COMPLETED, FAILED).
            createdAt (str): When this instance was created.
            lifecycleInfo (dict): Additional lifecycle information (e.g., error details).
    """

    def __init__(self, client, daemonTaskVersion=None, daemonTaskId=None, deploymentConversationId=None, lifecycle=None, createdAt=None, lifecycleInfo=None):
        super().__init__(client, None)
        self.daemon_task_version = daemonTaskVersion
        self.daemon_task_id = daemonTaskId
        self.deployment_conversation_id = deploymentConversationId
        self.lifecycle = lifecycle
        self.created_at = createdAt
        self.lifecycle_info = lifecycleInfo
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'daemon_task_version': repr(self.daemon_task_version), f'daemon_task_id': repr(self.daemon_task_id), f'deployment_conversation_id': repr(
            self.deployment_conversation_id), f'lifecycle': repr(self.lifecycle), f'created_at': repr(self.created_at), f'lifecycle_info': repr(self.lifecycle_info)}
        class_name = "DaemonTaskInstance"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'daemon_task_version': self.daemon_task_version, 'daemon_task_id': self.daemon_task_id, 'deployment_conversation_id':
                self.deployment_conversation_id, 'lifecycle': self.lifecycle, 'created_at': self.created_at, 'lifecycle_info': self.lifecycle_info}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class CustomDomain(AbstractApiClass):
    """
        Result of adding a custom domain to a hosted app

        Args:
            client (ApiClient): An authenticated API Client instance
            status (bool): Whether the custom domain was added successfully
            message (str): The message from the custom domain
            expectedNameservers (list): The expected nameservers for the custom domain
            currentNameservers (list): The current nameservers for the custom domain
    """

    def __init__(self, client, status=None, message=None, expectedNameservers=None, currentNameservers=None):
        super().__init__(client, None)
        self.status = status
        self.message = message
        self.expected_nameservers = expectedNameservers
        self.current_nameservers = currentNameservers
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'status': repr(self.status), f'message': repr(self.message), f'expected_nameservers': repr(
            self.expected_nameservers), f'current_nameservers': repr(self.current_nameservers)}
        class_name = "CustomDomain"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'status': self.status, 'message': self.message, 'expected_nameservers':
                self.expected_nameservers, 'current_nameservers': self.current_nameservers}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .email_domain import EmailDomain
from .return_class import AbstractApiClass


class WebAppProject(AbstractApiClass):
    """
        Web app project (_describeWebAppProject).

        Args:
            client (ApiClient): An authenticated API Client instance
            webAppProjectId (id): The project ID
            sourceDeploymentConversationId (id): Source deployment conversation ID
            deployedStatus (str): ACTIVE | NOT_DEPLOYED
            hostnames (list[dict]): List of hostnames and tags to which the app is deployed
            projectMetadata (dict): Project metadata
            projectType (str): web_app | web_service | mobile_app
            hostedDatabaseId (id): The ID of the hosted database
            hostedDevDatabaseId (id): The ID of the hosted dev database
            emailDomains (EmailDomain): List of EmailDomain (custom domains and email status for this project)
    """

    def __init__(self, client, webAppProjectId=None, sourceDeploymentConversationId=None, deployedStatus=None, hostnames=None, projectMetadata=None, projectType=None, hostedDatabaseId=None, hostedDevDatabaseId=None, emailDomains={}):
        super().__init__(client, webAppProjectId)
        self.web_app_project_id = webAppProjectId
        self.source_deployment_conversation_id = sourceDeploymentConversationId
        self.deployed_status = deployedStatus
        self.hostnames = hostnames
        self.project_metadata = projectMetadata
        self.project_type = projectType
        self.hosted_database_id = hostedDatabaseId
        self.hosted_dev_database_id = hostedDevDatabaseId
        self.email_domains = client._build_class(EmailDomain, emailDomains)
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'web_app_project_id': repr(self.web_app_project_id), f'source_deployment_conversation_id': repr(self.source_deployment_conversation_id), f'deployed_status': repr(self.deployed_status), f'hostnames': repr(self.hostnames), f'project_metadata': repr(
            self.project_metadata), f'project_type': repr(self.project_type), f'hosted_database_id': repr(self.hosted_database_id), f'hosted_dev_database_id': repr(self.hosted_dev_database_id), f'email_domains': repr(self.email_domains)}
        class_name = "WebAppProject"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'web_app_project_id': self.web_app_project_id, 'source_deployment_conversation_id': self.source_deployment_conversation_id, 'deployed_status': self.deployed_status, 'hostnames': self.hostnames, 'project_metadata': self.project_metadata,
                'project_type': self.project_type, 'hosted_database_id': self.hosted_database_id, 'hosted_dev_database_id': self.hosted_dev_database_id, 'email_domains': self._get_attribute_as_dict(self.email_domains)}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class SftpKey(AbstractApiClass):
    """
        An SFTP key

        Args:
            client (ApiClient): An authenticated API Client instance
            keyName (str): The name of the key
            publicKey (str): The public key
    """

    def __init__(self, client, keyName=None, publicKey=None):
        super().__init__(client, None)
        self.key_name = keyName
        self.public_key = publicKey
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'key_name': repr(
            self.key_name), f'public_key': repr(self.public_key)}
        class_name = "SftpKey"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'key_name': self.key_name, 'public_key': self.public_key}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



import dataclasses

from . import enums
from .abstract import _ApiClassFactory
from .dataset import DatasetConfig


@dataclasses.dataclass
class StreamingConnectorDatasetConfig(DatasetConfig):
    """
    An abstract class for dataset configs specific to streaming connectors.

    Args:
        streaming_connector_type (StreamingConnectorType): The type of streaming connector
    """
    streaming_connector_type: enums.StreamingConnectorType = dataclasses.field(default=None, repr=False, init=False)

    @classmethod
    def _get_builder(cls):
        return _StreamingConnectorDatasetConfigFactory


@dataclasses.dataclass
class KafkaDatasetConfig(StreamingConnectorDatasetConfig):
    """
    Dataset config for Kafka Streaming Connector

    Args:
        topic (str): The kafka topic to consume
    """
    topic: str = dataclasses.field(default=None)

    def __post_init__(self):
        self.streaming_connector_type = enums.StreamingConnectorType.KAFKA


@dataclasses.dataclass
class _StreamingConnectorDatasetConfigFactory(_ApiClassFactory):
    config_abstract_class = StreamingConnectorDatasetConfig
    config_class_key = 'streaming_connector_type'
    config_class_map = {
        enums.StreamingConnectorType.KAFKA: KafkaDatasetConfig,
    }



from .return_class import AbstractApiClass


class HostedArtifact(AbstractApiClass):
    """
        A hosted artifact being served by the platform.

        Args:
            client (ApiClient): An authenticated API Client instance
            hostnames (list): The urls at which the application is being hosted.
            artifactType (str): The type of artifact being hosted.
            llmArtifactId (str): The artifact id being hosted.
            lifecycle (str): The lifecycle of the artifact.
            externalApplicationId (str): Agent that deployed this application.
            deploymentConversationId (str): Conversation that created deployed this artifact, null if not applicable.
            conversationSequenceNumber (number(integer)): Conversation event associated with this artifact, null if not applicable.
            accessLevel (str): The access level of the hosted artifact (PUBLIC, PRIVATE, OWNER_ONLY, DEDICATED).
            isThrottled (bool): Whether the artifact has been temporarily suspended due to high resource usage.
    """

    def __init__(self, client, hostnames=None, artifactType=None, llmArtifactId=None, lifecycle=None, externalApplicationId=None, deploymentConversationId=None, conversationSequenceNumber=None, accessLevel=None, isThrottled=None):
        super().__init__(client, None)
        self.hostnames = hostnames
        self.artifact_type = artifactType
        self.llm_artifact_id = llmArtifactId
        self.lifecycle = lifecycle
        self.external_application_id = externalApplicationId
        self.deployment_conversation_id = deploymentConversationId
        self.conversation_sequence_number = conversationSequenceNumber
        self.access_level = accessLevel
        self.is_throttled = isThrottled
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'hostnames': repr(self.hostnames), f'artifact_type': repr(self.artifact_type), f'llm_artifact_id': repr(self.llm_artifact_id), f'lifecycle': repr(self.lifecycle), f'external_application_id': repr(
            self.external_application_id), f'deployment_conversation_id': repr(self.deployment_conversation_id), f'conversation_sequence_number': repr(self.conversation_sequence_number), f'access_level': repr(self.access_level), f'is_throttled': repr(self.is_throttled)}
        class_name = "HostedArtifact"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'hostnames': self.hostnames, 'artifact_type': self.artifact_type, 'llm_artifact_id': self.llm_artifact_id, 'lifecycle': self.lifecycle, 'external_application_id': self.external_application_id,
                'deployment_conversation_id': self.deployment_conversation_id, 'conversation_sequence_number': self.conversation_sequence_number, 'access_level': self.access_level, 'is_throttled': self.is_throttled}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class UserGroupObjectPermission(AbstractApiClass):
    """
        A user group object permission

        Args:
            client (ApiClient): An authenticated API Client instance
            userGroupId (str): The unique identifier of the user group.
            userGroupName (str): The name of the user group.
            objectId (str): The unique identifier of the object.
            permission (str): The permission level (e.g., 'ALL').
    """

    def __init__(self, client, userGroupId=None, userGroupName=None, objectId=None, permission=None):
        super().__init__(client, None)
        self.user_group_id = userGroupId
        self.user_group_name = userGroupName
        self.object_id = objectId
        self.permission = permission
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'user_group_id': repr(self.user_group_id), f'user_group_name': repr(
            self.user_group_name), f'object_id': repr(self.object_id), f'permission': repr(self.permission)}
        class_name = "UserGroupObjectPermission"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'user_group_id': self.user_group_id, 'user_group_name': self.user_group_name,
                'object_id': self.object_id, 'permission': self.permission}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class CodeBot(AbstractApiClass):
    """
        A bot option for CodeLLM

        Args:
            client (ApiClient): An authenticated API Client instance
            llmName (str): The name of the LLM.
            name (str): The name of the bot.
            coworkName (str): The display name of the bot in CoWork. Only available for select bots.
            imageUploadSupported (bool): Whether the LLM supports image upload.
            codeAgentSupported (bool): Whether the LLM supports code agent.
            codeEditSupported (bool): Whether the LLM supports code edit.
            isPremium (bool): Whether the LLM is a premium LLM.
            llmBotIcon (str): The icon of the LLM bot.
            provider (str): The provider of the LLM.
            isUserApiKeyAllowed (bool): Whether the LLM supports user API key.
            isRateLimited (bool): Whether the LLM is rate limited.
            apiKeyUrl (str): The URL to get the API key.
    """

    def __init__(self, client, llmName=None, name=None, coworkName=None, imageUploadSupported=None, codeAgentSupported=None, codeEditSupported=None, isPremium=None, llmBotIcon=None, provider=None, isUserApiKeyAllowed=None, isRateLimited=None, apiKeyUrl=None):
        super().__init__(client, None)
        self.llm_name = llmName
        self.name = name
        self.cowork_name = coworkName
        self.image_upload_supported = imageUploadSupported
        self.code_agent_supported = codeAgentSupported
        self.code_edit_supported = codeEditSupported
        self.is_premium = isPremium
        self.llm_bot_icon = llmBotIcon
        self.provider = provider
        self.is_user_api_key_allowed = isUserApiKeyAllowed
        self.is_rate_limited = isRateLimited
        self.api_key_url = apiKeyUrl
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'llm_name': repr(self.llm_name), f'name': repr(self.name), f'cowork_name': repr(self.cowork_name), f'image_upload_supported': repr(self.image_upload_supported), f'code_agent_supported': repr(self.code_agent_supported), f'code_edit_supported': repr(
            self.code_edit_supported), f'is_premium': repr(self.is_premium), f'llm_bot_icon': repr(self.llm_bot_icon), f'provider': repr(self.provider), f'is_user_api_key_allowed': repr(self.is_user_api_key_allowed), f'is_rate_limited': repr(self.is_rate_limited), f'api_key_url': repr(self.api_key_url)}
        class_name = "CodeBot"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'llm_name': self.llm_name, 'name': self.name, 'cowork_name': self.cowork_name, 'image_upload_supported': self.image_upload_supported, 'code_agent_supported': self.code_agent_supported, 'code_edit_supported': self.code_edit_supported,
                'is_premium': self.is_premium, 'llm_bot_icon': self.llm_bot_icon, 'provider': self.provider, 'is_user_api_key_allowed': self.is_user_api_key_allowed, 'is_rate_limited': self.is_rate_limited, 'api_key_url': self.api_key_url}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .drift_distribution import DriftDistribution
from .return_class import AbstractApiClass


class DriftDistributions(AbstractApiClass):
    """
        For either actuals or predicted values, how it has changed in the training data versus some specified window

        Args:
            client (ApiClient): An authenticated API Client instance
            labelDrift (DriftDistribution): A DriftDistribution describing column names and the range of values for label drift.
            predictionDrift (DriftDistribution): A DriftDistribution describing column names and the range of values for prediction drift.
            bpPredictionDrift (DriftDistribution): A DriftDistribution describing column names and the range of values for prediction drift, when the predictions come from BP.
    """

    def __init__(self, client, labelDrift={}, predictionDrift={}, bpPredictionDrift={}):
        super().__init__(client, None)
        self.label_drift = client._build_class(DriftDistribution, labelDrift)
        self.prediction_drift = client._build_class(
            DriftDistribution, predictionDrift)
        self.bp_prediction_drift = client._build_class(
            DriftDistribution, bpPredictionDrift)
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'label_drift': repr(self.label_drift), f'prediction_drift': repr(
            self.prediction_drift), f'bp_prediction_drift': repr(self.bp_prediction_drift)}
        class_name = "DriftDistributions"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'label_drift': self._get_attribute_as_dict(self.label_drift), 'prediction_drift': self._get_attribute_as_dict(
            self.prediction_drift), 'bp_prediction_drift': self._get_attribute_as_dict(self.bp_prediction_drift)}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class MediaArtifact(AbstractApiClass):
    """
        Media Artifact

        Args:
            client (ApiClient): An authenticated API Client instance
            mediaArtifactId (id): The ID of the media artifact
            mediaType (str): The type of media (IMAGE, VIDEO, AUDIO)
            info (dict): Metadata (width, height, mime_type, file_size_bytes, generation_model, generation_prompt, generation_params, duration_seconds)
            sourceDeploymentConversationId (id): The source conversation ID
            isFavorited (bool): Whether the artifact is favorited
            isShared (bool): Whether the artifact is shared publicly
            publicUrl (str): The permanent public URL (set after sharing)
            thumbnailUrl (str): Signed thumbnail URL (generated at read time)
            mediaUrl (str): Signed full media URL (generated at read time)
            createdAt (str): The creation timestamp
            updatedAt (str): The last update timestamp
    """

    def __init__(self, client, mediaArtifactId=None, mediaType=None, info=None, sourceDeploymentConversationId=None, isFavorited=None, isShared=None, publicUrl=None, thumbnailUrl=None, mediaUrl=None, createdAt=None, updatedAt=None):
        super().__init__(client, mediaArtifactId)
        self.media_artifact_id = mediaArtifactId
        self.media_type = mediaType
        self.info = info
        self.source_deployment_conversation_id = sourceDeploymentConversationId
        self.is_favorited = isFavorited
        self.is_shared = isShared
        self.public_url = publicUrl
        self.thumbnail_url = thumbnailUrl
        self.media_url = mediaUrl
        self.created_at = createdAt
        self.updated_at = updatedAt
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'media_artifact_id': repr(self.media_artifact_id), f'media_type': repr(self.media_type), f'info': repr(self.info), f'source_deployment_conversation_id': repr(self.source_deployment_conversation_id), f'is_favorited': repr(
            self.is_favorited), f'is_shared': repr(self.is_shared), f'public_url': repr(self.public_url), f'thumbnail_url': repr(self.thumbnail_url), f'media_url': repr(self.media_url), f'created_at': repr(self.created_at), f'updated_at': repr(self.updated_at)}
        class_name = "MediaArtifact"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'media_artifact_id': self.media_artifact_id, 'media_type': self.media_type, 'info': self.info, 'source_deployment_conversation_id': self.source_deployment_conversation_id, 'is_favorited': self.is_favorited,
                'is_shared': self.is_shared, 'public_url': self.public_url, 'thumbnail_url': self.thumbnail_url, 'media_url': self.media_url, 'created_at': self.created_at, 'updated_at': self.updated_at}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .api_class import ProblemType
from .return_class import AbstractApiClass


class ProblemType(AbstractApiClass):
    """
        Description of a problem type which is the common underlying problem for different use cases.

        Args:
            client (ApiClient): An authenticated API Client instance
            problemType (str): Name of the problem type
            requiredFeatureGroupType (str): The required feature group types to train for this problem type
            optionalFeatureGroupTypes (list[str]): The optional feature group types can be used to train for this problem type
            useCasesSupportCustomAlgorithm (list): A list of use cases that support custom algorithms
    """

    def __init__(self, client, problemType=None, requiredFeatureGroupType=None, optionalFeatureGroupTypes=None, useCasesSupportCustomAlgorithm=None):
        super().__init__(client, None)
        self.problem_type = problemType
        self.required_feature_group_type = requiredFeatureGroupType
        self.optional_feature_group_types = optionalFeatureGroupTypes
        self.use_cases_support_custom_algorithm = useCasesSupportCustomAlgorithm
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'problem_type': repr(self.problem_type), f'required_feature_group_type': repr(self.required_feature_group_type), f'optional_feature_group_types': repr(
            self.optional_feature_group_types), f'use_cases_support_custom_algorithm': repr(self.use_cases_support_custom_algorithm)}
        class_name = "ProblemType"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'problem_type': self.problem_type, 'required_feature_group_type': self.required_feature_group_type,
                'optional_feature_group_types': self.optional_feature_group_types, 'use_cases_support_custom_algorithm': self.use_cases_support_custom_algorithm}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class AgentChatMessage(AbstractApiClass):
    """
        A single chat message with Agent Chat.

        Args:
            client (ApiClient): An authenticated API Client instance
            role (str): The role of the message sender
            text (list[dict]): A list of text segments for the message
            docIds (list[str]): A list of IDs of the uploaded document if the message has
            keywordArguments (dict): User message only. A dictionary of keyword arguments used to generate response.
            segments (list[dict]): A list of segments for the message
            streamedData (str): The streamed data for the message
            streamedSectionData (list): A list of streamed section data for the message
            agentWorkflowNodeId (str): The workflow node name associated with the agent response.
    """

    def __init__(self, client, role=None, text=None, docIds=None, keywordArguments=None, segments=None, streamedData=None, streamedSectionData=None, agentWorkflowNodeId=None):
        super().__init__(client, None)
        self.role = role
        self.text = text
        self.doc_ids = docIds
        self.keyword_arguments = keywordArguments
        self.segments = segments
        self.streamed_data = streamedData
        self.streamed_section_data = streamedSectionData
        self.agent_workflow_node_id = agentWorkflowNodeId
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'role': repr(self.role), f'text': repr(self.text), f'doc_ids': repr(self.doc_ids), f'keyword_arguments': repr(self.keyword_arguments), f'segments': repr(
            self.segments), f'streamed_data': repr(self.streamed_data), f'streamed_section_data': repr(self.streamed_section_data), f'agent_workflow_node_id': repr(self.agent_workflow_node_id)}
        class_name = "AgentChatMessage"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'role': self.role, 'text': self.text, 'doc_ids': self.doc_ids, 'keyword_arguments': self.keyword_arguments, 'segments': self.segments,
                'streamed_data': self.streamed_data, 'streamed_section_data': self.streamed_section_data, 'agent_workflow_node_id': self.agent_workflow_node_id}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class FeatureDriftRecord(AbstractApiClass):
    """
        Value of each type of drift

        Args:
            client (ApiClient): An authenticated API Client instance
            name (str): Name of feature.
            distance (float): Symmetric sum of KL divergences between the training distribution and the range of values in the specified window.
            jsDistance (float): JS divergence between the training distribution and the range of values in the specified window.
            wsDistance (float): Wasserstein distance between the training distribution and the range of values in the specified window.
            ksStatistic (float): Kolmogorov-Smirnov statistic computed between the training distribution and the range of values in the specified window.
            psi (float): Population stability index computed between the training distribution and the range of values in the specified window.
            csi (float): Characteristic Stability Index computed between the training distribution and the range of values in the specified window.
            chiSquare (float): Chi-square statistic computed between the training distribution and the range of values in the specified window.
    """

    def __init__(self, client, name=None, distance=None, jsDistance=None, wsDistance=None, ksStatistic=None, psi=None, csi=None, chiSquare=None):
        super().__init__(client, None)
        self.name = name
        self.distance = distance
        self.js_distance = jsDistance
        self.ws_distance = wsDistance
        self.ks_statistic = ksStatistic
        self.psi = psi
        self.csi = csi
        self.chi_square = chiSquare
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'name': repr(self.name), f'distance': repr(self.distance), f'js_distance': repr(self.js_distance), f'ws_distance': repr(
            self.ws_distance), f'ks_statistic': repr(self.ks_statistic), f'psi': repr(self.psi), f'csi': repr(self.csi), f'chi_square': repr(self.chi_square)}
        class_name = "FeatureDriftRecord"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'name': self.name, 'distance': self.distance, 'js_distance': self.js_distance, 'ws_distance': self.ws_distance,
                'ks_statistic': self.ks_statistic, 'psi': self.psi, 'csi': self.csi, 'chi_square': self.chi_square}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class Address(AbstractApiClass):
    """
        Address object

        Args:
            client (ApiClient): An authenticated API Client instance
            addressLine1 (str): The first line of the address
            addressLine2 (str): The second line of the address
            city (str): The city
            stateOrProvince (str): The state or province
            postalCode (str): The postal code
            country (str): The country
            additionalInfo (str): Additional information for invoice
            includeReverseCharge (bool): Whether the organization needs the reverse charge mechanism applied to invoices.
    """

    def __init__(self, client, addressLine1=None, addressLine2=None, city=None, stateOrProvince=None, postalCode=None, country=None, additionalInfo=None, includeReverseCharge=None):
        super().__init__(client, None)
        self.address_line_1 = addressLine1
        self.address_line_2 = addressLine2
        self.city = city
        self.state_or_province = stateOrProvince
        self.postal_code = postalCode
        self.country = country
        self.additional_info = additionalInfo
        self.include_reverse_charge = includeReverseCharge
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'address_line_1': repr(self.address_line_1), f'address_line_2': repr(self.address_line_2), f'city': repr(self.city), f'state_or_province': repr(self.state_or_province), f'postal_code': repr(
            self.postal_code), f'country': repr(self.country), f'additional_info': repr(self.additional_info), f'include_reverse_charge': repr(self.include_reverse_charge)}
        class_name = "Address"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'address_line_1': self.address_line_1, 'address_line_2': self.address_line_2, 'city': self.city, 'state_or_province': self.state_or_province,
                'postal_code': self.postal_code, 'country': self.country, 'additional_info': self.additional_info, 'include_reverse_charge': self.include_reverse_charge}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .api_class import PythonFunctionArgument
from .code_source import CodeSource
from .pipeline_step_version import PipelineStepVersion
from .return_class import AbstractApiClass


class PipelineVersion(AbstractApiClass):
    """
        A version of a pipeline.

        Args:
            client (ApiClient): An authenticated API Client instance
            pipelineName (str): The name of the pipeline this step is a part of.
            pipelineId (str): The reference to the pipeline this step belongs to.
            pipelineVersion (str): The reference to this pipeline version.
            createdAt (str): The date and time which this pipeline version was created.
            updatedAt (str): The date and time which this pipeline version was updated.
            completedAt (str): The date and time which this pipeline version was updated.
            status (str): The status of the pipeline version.
            error (str): The relevant error, if the status is FAILED.
            stepVersions (PipelineStepVersion): A list of the pipeline step versions.
            codeSource (CodeSource): information on the source code
            pipelineVariableMappings (PythonFunctionArgument): A description of the function variables into the pipeline.
    """

    def __init__(self, client, pipelineName=None, pipelineId=None, pipelineVersion=None, createdAt=None, updatedAt=None, completedAt=None, status=None, error=None, stepVersions={}, codeSource={}, pipelineVariableMappings={}):
        super().__init__(client, pipelineVersion)
        self.pipeline_name = pipelineName
        self.pipeline_id = pipelineId
        self.pipeline_version = pipelineVersion
        self.created_at = createdAt
        self.updated_at = updatedAt
        self.completed_at = completedAt
        self.status = status
        self.error = error
        self.step_versions = client._build_class(
            PipelineStepVersion, stepVersions)
        self.code_source = client._build_class(CodeSource, codeSource)
        self.pipeline_variable_mappings = client._build_class(
            PythonFunctionArgument, pipelineVariableMappings)
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'pipeline_name': repr(self.pipeline_name), f'pipeline_id': repr(self.pipeline_id), f'pipeline_version': repr(self.pipeline_version), f'created_at': repr(self.created_at), f'updated_at': repr(self.updated_at), f'completed_at': repr(
            self.completed_at), f'status': repr(self.status), f'error': repr(self.error), f'step_versions': repr(self.step_versions), f'code_source': repr(self.code_source), f'pipeline_variable_mappings': repr(self.pipeline_variable_mappings)}
        class_name = "PipelineVersion"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'pipeline_name': self.pipeline_name, 'pipeline_id': self.pipeline_id, 'pipeline_version': self.pipeline_version, 'created_at': self.created_at, 'updated_at': self.updated_at, 'completed_at': self.completed_at, 'status': self.status,
                'error': self.error, 'step_versions': self._get_attribute_as_dict(self.step_versions), 'code_source': self._get_attribute_as_dict(self.code_source), 'pipeline_variable_mappings': self._get_attribute_as_dict(self.pipeline_variable_mappings)}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}

    def refresh(self):
        """
        Calls describe and refreshes the current object's fields

        Returns:
            PipelineVersion: The current object
        """
        self.__dict__.update(self.describe().__dict__)
        return self

    def describe(self):
        """
        Describes a specified pipeline version

        Args:
            pipeline_version (str): Unique string identifier for the pipeline version

        Returns:
            PipelineVersion: Object describing the pipeline version
        """
        return self.client.describe_pipeline_version(self.pipeline_version)

    def reset(self, steps: list = None, include_downstream_steps: bool = True):
        """
        Reruns a pipeline version for the given steps and downstream steps if specified.

        Args:
            steps (list): List of pipeline step names to rerun.
            include_downstream_steps (bool): Whether to rerun downstream steps from the steps you have passed

        Returns:
            PipelineVersion: Object describing the pipeline version
        """
        return self.client.reset_pipeline_version(self.pipeline_version, steps, include_downstream_steps)

    def list_logs(self):
        """
        Gets the logs for the steps in a given pipeline version.

        Args:
            pipeline_version (str): The id of the pipeline version.

        Returns:
            PipelineVersionLogs: Object describing the logs for the steps in the pipeline.
        """
        return self.client.list_pipeline_version_logs(self.pipeline_version)

    def skip_pending_steps(self):
        """
        Skips pending steps in a pipeline version.

        Args:
            pipeline_version (str): The id of the pipeline version.

        Returns:
            PipelineVersion: Object describing the pipeline version
        """
        return self.client.skip_pending_pipeline_version_steps(self.pipeline_version)

    def wait_for_pipeline(self, timeout=1200):
        """
        A waiting call until all the stages in a pipeline version have completed.

        Args:
            timeout (int): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
        """
        return self.client._poll(self, {'PENDING', 'RUNNING'}, timeout=timeout)

    def get_status(self):
        """
        Gets the status of the pipeline version.

        Returns:
            str: A string describing the status of a pipeline version (pending, running, complete, etc.).
        """
        return self.describe().status



from .return_class import AbstractApiClass


class ApplicationConnector(AbstractApiClass):
    """
        A connector to an external service

        Args:
            client (ApiClient): An authenticated API Client instance
            applicationConnectorId (str): The unique ID for the connection.
            service (str): The service this connection connects to
            serviceName (str): For OAuth services, the specific provider name (e.g., 'spotify')
            name (str): A user-friendly name for the service
            createdAt (str): When the API key was created
            status (str): The status of the Application Connector
            auth (dict): Non-secret connection information for this connector
            baseConnector (str): The hashed ID of the config connector this user connector is based on (for config connector flows)
            createdBy (str): The email of the user who created this connector.
    """

    def __init__(self, client, applicationConnectorId=None, service=None, serviceName=None, name=None, createdAt=None, status=None, auth=None, baseConnector=None, createdBy=None):
        super().__init__(client, applicationConnectorId)
        self.application_connector_id = applicationConnectorId
        self.service = service
        self.service_name = serviceName
        self.name = name
        self.created_at = createdAt
        self.status = status
        self.auth = auth
        self.base_connector = baseConnector
        self.created_by = createdBy
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'application_connector_id': repr(self.application_connector_id), f'service': repr(self.service), f'service_name': repr(self.service_name), f'name': repr(
            self.name), f'created_at': repr(self.created_at), f'status': repr(self.status), f'auth': repr(self.auth), f'base_connector': repr(self.base_connector), f'created_by': repr(self.created_by)}
        class_name = "ApplicationConnector"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'application_connector_id': self.application_connector_id, 'service': self.service, 'service_name': self.service_name, 'name': self.name,
                'created_at': self.created_at, 'status': self.status, 'auth': self.auth, 'base_connector': self.base_connector, 'created_by': self.created_by}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}

    def rename(self, name: str):
        """
        Renames a Application Connector

        Args:
            name (str): A new name for the application connector.
        """
        return self.client.rename_application_connector(self.application_connector_id, name)

    def delete(self):
        """
        Delete an application connector.

        Args:
            application_connector_id (str): The unique identifier for the application connector.
        """
        return self.client.delete_application_connector(self.application_connector_id)

    def list_objects(self):
        """
        Lists querable objects in the application connector.

        Args:
            application_connector_id (str): Unique string identifier for the application connector.
        """
        return self.client.list_application_connector_objects(self.application_connector_id)

    def verify(self):
        """
        Checks if Abacus.AI can access the application using the provided application connector ID.

        Args:
            application_connector_id (str): Unique string identifier for the application connector.
        """
        return self.client.verify_application_connector(self.application_connector_id)



from .image_gen_model_options import ImageGenModelOptions
from .return_class import AbstractApiClass


class ImageGenModel(AbstractApiClass):
    """
        Image generation model

        Args:
            client (ApiClient): An authenticated API Client instance
            displayName (str): The display name for the UI component.
            type (str): The type of the UI component.
            valueType (str): The data type of the values within the UI component.
            optional (bool): Whether the selection of a value is optional.
            default (str): The default value for the image generation model.
            helptext (str): The helptext for the UI component.
            options (ImageGenModelOptions): The options of models available for image generation.
    """

    def __init__(self, client, displayName=None, type=None, valueType=None, optional=None, default=None, helptext=None, options={}):
        super().__init__(client, None)
        self.display_name = displayName
        self.type = type
        self.value_type = valueType
        self.optional = optional
        self.default = default
        self.helptext = helptext
        self.options = client._build_class(ImageGenModelOptions, options)
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'display_name': repr(self.display_name), f'type': repr(self.type), f'value_type': repr(self.value_type), f'optional': repr(
            self.optional), f'default': repr(self.default), f'helptext': repr(self.helptext), f'options': repr(self.options)}
        class_name = "ImageGenModel"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'display_name': self.display_name, 'type': self.type, 'value_type': self.value_type, 'optional': self.optional,
                'default': self.default, 'helptext': self.helptext, 'options': self._get_attribute_as_dict(self.options)}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class CodeAutocompleteEditPredictionResponse(AbstractApiClass):
    """
        A autocomplete response from an LLM

        Args:
            client (ApiClient): An authenticated API Client instance
            autocompleteResponse (str): autocomplete code
            showAutocomplete (bool): Whether to show autocomplete in the client
    """

    def __init__(self, client, autocompleteResponse=None, showAutocomplete=None):
        super().__init__(client, None)
        self.autocomplete_response = autocompleteResponse
        self.show_autocomplete = showAutocomplete
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'autocomplete_response': repr(
            self.autocomplete_response), f'show_autocomplete': repr(self.show_autocomplete)}
        class_name = "CodeAutocompleteEditPredictionResponse"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'autocomplete_response': self.autocomplete_response,
                'show_autocomplete': self.show_autocomplete}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
